@@ -106,7 +106,7 @@ void Palapeli::View::mouseMoveEvent(QMouseEvent* event)
 	event->accept();
 	//send a stripped QMouseEvent to base class to update resizeAnchor() etc.
 	QMouseEvent modifiedEvent(event->type(),
-		event->pos(), event->globalPos(),
+		event->pos(), event->globalPosition().toPoint(),
 		Qt::NoButton, Qt::NoButton, event->modifiers()
 	);
 	QGraphicsView::mouseMoveEvent(&modifiedEvent);
